@@ -25,7 +25,8 @@
 
 setMethod("crossTable", signature(x = "itemMatrix"),
     function(x) {
-        m <- .Call("R_crosstab_ngCMatrix", x@data, NULL, TRUE)
+        m <- .Call("R_crosstab_ngCMatrix", x@data, NULL, TRUE,
+		PACKAGE="arules")
         if (is.null(dimnames(m)))
             dimnames(m) <- list(itemLabels(x), itemLabels(x))
         m
