@@ -1,3 +1,23 @@
+#######################################################################
+# arules - Mining Association Rules and Frequent Itemsets
+# Copyrigth (C) 2011 Michael Hahsler, Christian Buchta, 
+#			Bettina Gruen and Kurt Hornik
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+
 
 ##***************************************************************
 ## read/write functions
@@ -16,13 +36,13 @@
 }
 
 read.transactions <-
-function(file, format = c("basket", "single"), sep = NULL, cols = NULL, rm.duplicates = FALSE)
+function(file, format = c("basket", "single"), sep = NULL, cols = NULL, rm.duplicates = FALSE, encoding="unknown")
 {
     format <- match.arg(format)
     if (format == "basket") {
         if (is.null(sep))
             sep <- "[ \t]+"
-        data <- strsplit(readLines(file), split = sep)
+        data <- strsplit(readLines(file, encoding=encoding), split = sep)
         if (!is.null(cols)) {
             if (!(is(cols, "numeric") && (length(cols) == 1)))
                 stop("'cols' must be a numeric scalar for 'basket'.")
@@ -34,17 +54,34 @@ function(file, format = c("basket", "single"), sep = NULL, cols = NULL, rm.dupli
             data <- .rm.duplicates(data)
         return(as(data,"transactions"))   
     }
+    
     ## If format is "single", have lines with TIDs and IIDs in the
     ## columns specified by 'cols'.
+
+    ## If cols is a character vector of length 2 we assume the file
+    ## has a header with colnames (added by F. Leisch)
+    skip <- 0
+    if(is(cols, "character") && (length(cols) == 2)){
+        colnames <- scan(file = file, what="", sep = sep,
+                         quiet = TRUE, nlines=1)
+        cols <- match(cols, colnames)
+        if(any(is.na(cols)))
+            stop("'cols' does not match 2 entries in header of file.")
+        skip <- 1
+    }
+
+    ## Else we get the numbers of the columns directly
     if (!(is(cols, "numeric") && (length(cols) == 2)))
-        stop("'cols' must be a numeric vector of length 2 for 'single'.")
+        stop("'cols' must be a numeric or character vector of length 2 for 'single'.")
+    
     cols <- as(cols, "integer")
     ## Thanks to BDR for indicating how to only read in the relevant
     ## columns.
     what <- vector("list", length = max(cols))
     what[cols] <- ""
     entries <- scan(file = file, sep = sep, what = what, flush = TRUE,
-        quiet = TRUE)
+                    quiet = TRUE, skip = skip)
+    
     entries <- split(entries[[cols[2]]], entries[[cols[1]]])
     if (rm.duplicates)
         entries <- .rm.duplicates(entries)
@@ -52,6 +89,7 @@ function(file, format = c("basket", "single"), sep = NULL, cols = NULL, rm.dupli
 }
 
 ## write transactions and associations
+### FIXME: Quote does not work for basket format!
 
 setMethod("WRITE", signature(x = "transactions"),
 	function(x, file = "", format = c("basket", "single"), 
@@ -61,6 +99,7 @@ setMethod("WRITE", signature(x = "transactions"),
 	    if (format == "basket") {
 		l <- LIST(x)
 		dat <- unlist(list(lapply(l, paste, collapse=sep)))
+		if(quote) warning("Quote not implemented for basket format!")
 		write(dat, file=file, ...)
 	    } else { 
 		l <- LIST(x)
